@@ -7,7 +7,7 @@
 """
 
 from ..data_model import ValueType, OntologyTerm
-from ..warnings import warn
+from ..warnings import warn, BioSimulatorsWarning
 import json
 import numpy
 import re
@@ -16,6 +16,8 @@ __all__ = [
     'are_lists_equal', 'none_sorted', 'assert_exception',
     'validate_value', 'validate_str_value', 'format_value', 'parse_value',
     'patch_dict', 'pad_arrays_to_consistent_shapes',
+    'flatten_nested_list_of_strings',
+    'raise_errors_warnings',
 ]
 
 
@@ -326,3 +328,51 @@ def pad_arrays_to_consistent_shapes(arrays):
         padded_arrays.append(array)
 
     return padded_arrays
+
+
+def flatten_nested_list_of_strings(nested_list, prefix='- ', indent=' ' * 2):
+    """ Flatten a nested list of strings
+
+    Args:
+        nested_list (nested :obj:`list` of :obj:`str`): nested list of string
+        prefix (:obj:`str`, optional): prefix
+        indentation (:obj:`str`, optional): indentation
+
+    Returns:
+        :obj:`str`: flattened string
+    """
+    flattened = []
+    for item in nested_list:
+        flattened.append(prefix + item[0].replace('\n', '\n' + ' ' * len(prefix)))
+        if len(item) > 1:
+            flattened.append(
+                indent
+                + flatten_nested_list_of_strings(item[1], prefix=prefix, indent=indent).replace('\n', '\n' + indent)
+            )
+
+    return '\n'.join(flattened)
+
+
+def raise_errors_warnings(errors, warnings=None, error_summary=None, warning_summary=None):
+    """ Raises errors and warnings
+
+    Args:
+        errors (nested :obj:`list` of :obj:`str`): errors
+        warnings (nested :obj:`list` of :obj:`str`): warnings
+        error_summary (:obj:`str`, optional): summary of errors
+        warning_summary (:obj:`str`, optional): summary of warnings
+
+    Raises:
+        :obj:`ValueError`: if errors
+    """
+    if warnings:
+        msg = flatten_nested_list_of_strings(warnings)
+        if warning_summary:
+            msg = warning_summary + '\n  ' + msg.replace('\n', '\n  ')
+        warn(msg, BioSimulatorsWarning)
+
+    if errors:
+        msg = flatten_nested_list_of_strings(errors)
+        if error_summary:
+            msg = error_summary + '\n  ' + msg.replace('\n', '\n  ')
+        raise ValueError(msg)
